@@ -19,7 +19,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -44,15 +44,16 @@
 #include <kio/global.h>
 #include <kfileitem.h>
 #include <kapplication.h>
+#include <kglobal.h>
 
 // ark includes
 #include "arkwidget.h"
+#include "filelistview.h"
 #include "compressedfile.h"
 
 // encapsulates the idea of a compressed file
 
-CompressedFile::CompressedFile( ArkWidget *_gui,
-		  const QString & _fileName, const QString & _openAsMimeType )
+CompressedFile::CompressedFile( ArkWidget *_gui, const QString & _fileName, const QString & _openAsMimeType )
   : Arch( _gui, _fileName )
 {
   m_tempDirectory = NULL;
@@ -63,7 +64,8 @@ CompressedFile::CompressedFile( ArkWidget *_gui,
   m_tempDirectory->setAutoDelete( true );
   m_tmpdir = m_tempDirectory->name();
   initData();
-  verifyUtilityIsAvailable(m_archiver_program, m_unarchiver_program);
+  verifyCompressUtilityIsAvailable( m_archiver_program );
+  verifyUncompressUtilityIsAvailable( m_unarchiver_program );
 
   if (!QFile::exists(_fileName))
   {
@@ -83,23 +85,14 @@ CompressedFile::~CompressedFile()
 
 void CompressedFile::setHeaders()
 {
-  kdDebug(1601) << "+CompressedFile::setHeaders" << endl;
-  QStringList list;
+  ColumnList list;
+  list.append(FILENAME_COLUMN);
+  list.append(PERMISSION_COLUMN);
+  list.append(OWNER_COLUMN);
+  list.append(GROUP_COLUMN);
+  list.append(SIZE_COLUMN);
 
-  list.append(FILENAME_STRING);
-  list.append(PERMISSION_STRING);
-  list.append(OWNER_STRING);
-  list.append(GROUP_STRING);
-  list.append(SIZE_STRING);
-
-  // which columns to align right
-  int *alignRightCols = new int[1];
-  alignRightCols[0] = 3;
-
-  m_gui->setHeaders(&list, alignRightCols, 1);
-  delete [] alignRightCols;
-
-  kdDebug(1601) << "-CompressedFile::setHeaders" << endl;
+  emit headers(list);
 }
 
 void CompressedFile::initData()
@@ -138,9 +131,9 @@ void CompressedFile::initData()
     }
     if ( mimeType == "application/x-compress" )
     {
-        m_unarchiver_program = "uncompress";
-        m_archiver_program = "compress";
-        m_defaultExtensions = ".Z";
+        m_unarchiver_program = KGlobal::dirs()->findExe( "uncompress" ).isNull()? "gunzip" : "uncompress";
+        m_archiver_program   = "compress";
+        m_defaultExtensions  = ".Z";
     }
 
 }
@@ -172,11 +165,14 @@ void CompressedFile::open()
   KURL src, target;
   src.setPath( m_filename );
   target.setPath( m_tmpfile );
-  KIO::NetAccess::copy( m_filename, m_tmpfile, m_gui );
 
-  kdDebug(1601) << "Temp file name is " << m_tmpfile << endl;
+  KIO::NetAccess::copy( src, target, m_gui );
+  kdDebug(1601) << "Temp file name is " << target << endl;
 
-  KProcess *kp = new KProcess;
+  if ( !KIO::NetAccess::exists( target, true, NULL ) )
+    return;
+
+  KProcess *kp = m_currentProcess = new KProcess;
   kp->clearArguments();
   *kp << m_unarchiver_program << "-f" ;
   if ( m_unarchiver_program == "lzop")
@@ -223,7 +219,7 @@ void CompressedFile::slotUncompressDone(KProcess *_kp)
   }
 
   delete _kp;
-  _kp = 0;
+  _kp = m_currentProcess = 0;
 
   if ( !bSuccess )
   {
@@ -270,9 +266,11 @@ void CompressedFile::addFile( const QStringList &urls )
   Q_ASSERT(m_gui->getNumFilesInArchive() == 0);
   Q_ASSERT(urls.count() == 1);
 
-  QString file = urls.first();
-  if (file.left(5) == "file:")
-    file = file.right(file.length() - 5);
+  KURL url = KURL::fromPathOrURL(urls.first());
+  Q_ASSERT(url.isLocalFile());
+
+  QString file;
+  file = url.path();
 
   KProcess proc;
   proc << "cp" << file << m_tmpdir;
@@ -280,13 +278,13 @@ void CompressedFile::addFile( const QStringList &urls )
 
   m_tmpfile = file.right(file.length()
 			 - file.findRev("/")-1);
-  m_tmpfile = m_tmpdir + "/" + m_tmpfile;
+  m_tmpfile = m_tmpdir + '/' + m_tmpfile;
 
   kdDebug(1601) << "Temp file name is " << m_tmpfile << endl;
 
   kdDebug(1601) << "File is " << file << endl;
 
-  KProcess *kp = new KProcess;
+  KProcess *kp = m_currentProcess = new KProcess;
   kp->clearArguments();
 
   // lzop hack, see comment in tar.cpp createTmp()
@@ -338,19 +336,18 @@ void CompressedFile::slotAddDone(KProcess *_kp)
   slotAddExited(_kp);
 }
 
-void CompressedFile::unarchFile(QStringList *, const QString & _destDir,
-				bool /*viewFriendly*/)
+void CompressedFile::unarchFileInternal()
 {
-  if (_destDir != m_tmpdir)
+  if (m_destDir != m_tmpdir)
     {
       QString dest;
-      if (_destDir.isEmpty() || _destDir.isNull())
+      if (m_destDir.isEmpty() || m_destDir.isNull())
       {
           kdError(1601) << "There was no extract directory given." << endl;
           return;
       }
       else
-          dest=_destDir;
+          dest=m_destDir;
 
       KProcess proc;
       proc << "cp" << m_tmpfile << dest;
@@ -364,11 +361,9 @@ void CompressedFile::remove(QStringList *)
   kdDebug(1601) << "+CompressedFile::remove" << endl;
   QFile::remove(m_tmpfile);
 
-  // delete the compressed file but then create it empty in case someone
+  // do not delete but truncate the compressed file in case someone
   // does a reload and finds it no longer exists!
-  QFile::remove(m_filename);
-
-  ::close(::open(QFile::encodeName(m_filename), O_WRONLY | O_CREAT | O_EXCL));
+  truncate(QFile::encodeName(m_filename), 0);
 
   m_tmpfile = "";
   emit sigDelete(true);
