@@ -244,7 +244,13 @@ void ApmConfig::save()
 
 void ApmConfig::load()
 {
-       	config->setGroup("ApmDefault");
+	load( false );
+}
+
+void ApmConfig::load(bool useDefaults)
+{
+	     config->setReadDefaults( useDefaults );
+        config->setGroup("ApmDefault");
         enablestandby = config->readBoolEntry("EnableStandby", true);
         enableStandby->setChecked(enablestandby);
         enablesuspend = config->readBoolEntry("EnableSuspend", true);
@@ -253,20 +259,12 @@ void ApmConfig::load()
         enablesoftwaresuspend = config->readBoolEntry("EnableHibernate", false);
 	if (enableSoftwareSuspendHibernate)
         	enableSoftwareSuspendHibernate->setChecked(enablesoftwaresuspend);
-        changed(false);
+        emit changed(useDefaults);
 }
 
 void ApmConfig::defaults()
 {
-        enablestandby = true;
-        enableStandby->setChecked(enablestandby);
-        enablesuspend = true;
-        enableSuspend->setChecked(enablesuspend);
-        enablesoftwaresuspend = false;
-        if (enableSoftwareSuspendHibernate)
-		enableSoftwareSuspendHibernate->setChecked(enablesoftwaresuspend);
-
-        changed(true);
+	     load( true );
 }
 
 
